==> moodle_1.3.1.orig.tar.gz: moodle/lang/ca/resource.php <==
<?PHP // $Id: resource.php,v 1.10 2004/05/25 11:48:33 carlesbellver Exp $ 
      // resource.php - created with Moodle 1.3 (2004052500)


$string['addresource'] = 'Afegeix un recurs';
$string['chooseafile'] = 'Trieu o pengeu un fitxer';
$string['configdefaulturl'] = 'Aquest valor s\'utilitza per omplir per defecte el camp URL quan s\'est creant un nou recurs basat en URL.';
$string['configfilterexternalpages'] = 'Si habiliteu aquest parmetre, tots els recursos externs (pgines web, fitxers HTML penjats) seran processats pels filtres definits en aquest lloc (p. e. s\'hi podran afegir enllaos automtics a un glossari). Activar aquesta opci pot alentir significativament les pgines dels cursos; utilitzeu-la amb precauci i noms si realment la necessiteu.';
$string['configframesize'] = 'Quan una pgina web o un fitxer penjat es visualitzen dins d\'un marc, aquest valor s la mida (en pxels) del marc superior (el que cont la navegaci).';
$string['configpopup'] = 'Quan s\'est afegint un nou recurs que es pugui visualitzar en una finestra emergent, aquesta opci ha d\'estar habilitada per defecte?';
$string['configpopupdirectories'] = 'Les finestres emergents han de mostrar per defecte els enllaos del directori del navegador?';
$string['configpopupheight'] = 'Quina alada han de tenir per defecte les noves finestres emergents?';
$string['configpopuplocation'] = 'Les finestres emergents han de mostrar per defecte la barra d\'ubicaci?';
$string['configpopupmenubar'] = 'Les finestres emergents han de mostrar per defecte la barra de mens?';
$string['configpopupresizable'] = 'Les finestres emergents han de ser per defecte redimensionables?';
$string['configpopupscrollbars'] = 'Les finestres emergents han de permetre per defecte el desplaament?';
$string['configpopupstatus'] = 'Les finestres emergents han de mostrar per defecte la barra d\'estat?';
$string['configpopuptoolbar'] = 'Les finestres emergents han de mostrar per defecte la barra d\'eines?';
$string['configpopupwidth'] = 'Quina amplada han de tenir per defecte les noves finestres emergents?';
$string['configwebsearch'] = 'Quan s\'est afegint un URL com a pgina web o com a enlla web, aquesta ubicaci s\'ofereix a l\'usuari per ajudar-lo a cerca l\'URL que desitgi.';
$string['directlink'] = 'Enlla directe a aquest fitxer';
$string['directoryinfo'] = 'Es visualitzaran tots els fitxers del directori escollit.';
$string['editingaresource'] = 'S\'est editant un recurs';
$string['example'] = 'Exemple';
$string['examplereference'] = 'Tobin, K. & Tippins, D (1993) Constructivism as a Referent for Teaching and Learning. In: K. Tobin (Ed) The Practice of Constructivism in Science Education, pp 3-21, Lawrence-Erlbaum, Hillsdale, NJ.';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = 'Ha sorgit un error quan s\'intentava recuperar la pgina web (probablement l\'URL s erroni).';
$string['fetcherror'] = 'Ha sorgit un error quan s\'intentava recuperar la pgina web.';
$string['fetchservererror'] = 'Ha sorgit un error quan s\'intentava recuperar la pgina web (probablement un error de programa).</p>';
$string['filename'] = 'Nom del fitxer';
$string['filtername'] = 'Enllaos automtics a recursos';
$string['fulltext'] = 'Text complet';
$string['htmlfragment'] = 'Fragment HTML';
$string['maindirectory'] = 'Directori principal';
$string['modulename'] = 'Recurs';
$string['modulenameplural'] = 'Recursos';
$string['neverseen'] = 'Mai vist';
$string['newdirectories'] = 'Mostra els enllaos del directori del navegador';
$string['newfullscreen'] = 'Omple la pantalla completa';
$string['newheight'] = 'Alada per defecte de la finestra (en pxels)';
$string['newlocation'] = 'Mostra la barra d\'ubicaci';
$string['newmenubar'] = 'Mostra la barra de mens';
$string['newresizable'] = 'Permet redimensionar la finestra';
$string['newscrollbars'] = 'Permet el desplaament dins de la finestra';
$string['newstatus'] = 'Mostra la barra d\'estat';
$string['newtoolbar'] = 'Mostra la barra d\'eines';
$string['newwidth'] = 'Amplada de la finestra (en pxels)';
$string['newwindow'] = 'Nova finestra';
$string['newwindowopen'] = 'Mostra el material en una nova finestra emergent';
$string['note'] = 'Nota';
$string['notefile'] = 'Per penjar ms fitxers al curs (de manera que apareguin en aquesta llista) feu servir l\'<a href=$a >Gestor de fitxers</a>.';
$string['notypechosen'] = 'Heu de triar un tipus. Torneu enrere i proveu una altra vegada.';
$string['popupresource'] = 'Aquest recurs ha d\'aparixer en una finestra emergent.';
$string['popupresourcelink'] = 'Si no, feu clic aqu: $a';
$string['resourcetype'] = 'Tipus de recurs';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina web';
$string['resourcetype3'] = 'Fitxer penjat';
$string['resourcetype4'] = 'Text';
$string['resourcetype5'] = 'Enlla web';
$string['resourcetype6'] = 'Text HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Text wiki';
$string['resourcetype9'] = 'Directori';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/ca/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 unstable development (2004083000)


$string['addresource'] = 'Afegeix un recurs';
$string['chooseafile'] = 'Trieu o pengeu un fitxer';
$string['chooseparameter'] = 'Trieu un parmetre';
$string['configdefaulturl'] = 'Aquest valor s\'utilitza per omplir per defecte el camp URL quan s\'est creant un nou recurs basat en URL.';
$string['configfilterexternalpages'] = 'Si habiliteu aquest parmetre, tots els recursos externs (pgines web, fitxers HTML penjats) seran processats pels filtres definits en aquest lloc (p. e. s\'hi podran afegir enllaos automtics a un glossari). Activar aquesta opci pot alentir significativament les pgines dels cursos; utilitzeu-la amb precauci i noms si realment la necessiteu.';
$string['configframesize'] = 'Quan una pgina web o un fitxer penjat es visualitzen dins d\'un marc, aquest valor s la mida (en pxels) del marc superior (el que cont la navegaci).';
$string['configparametersettings'] = 'Defineix el valor per defecte de la secci de configuraci de Parmetres quan s\'afegeixen alguns nous recursos. Desprs de la primera vegada esdev una preferncia individual de l\'usuari.';
$string['configpopup'] = 'Quan s\'est afegint un nou recurs que es pugui visualitzar en una finestra emergent, aquesta opci ha d\'estar habilitada per defecte?';
$string['configpopupdirectories'] = 'Les finestres emergents han de mostrar per defecte la barra d\'enllaos del navegador?';
$string['configpopupheight'] = 'Quina alada han de tenir per defecte les noves finestres emergents?';
$string['configpopuplocation'] = 'Les finestres emergents han de mostrar per defecte la barra d\'ubicaci?';
$string['configpopupmenubar'] = 'Les finestres emergents han de mostrar per defecte la barra de mens?';
$string['configpopupresizable'] = 'Les finestres emergents han de ser per defecte redimensionables?';
$string['configpopupscrollbars'] = 'Les finestres emergents han de permetre per defecte el desplaament?';
$string['configpopupstatus'] = 'Les finestres emergents han de mostrar per defecte la barra d\'estat?';
$string['configpopuptoolbar'] = 'Les finestres emergents han de mostrar per defecte la barra d\'eines?';
$string['configpopupwidth'] = 'Quina amplada han de tenir per defecte les noves finestres emergents?';
$string['configsecretphrase'] = 'Aquesta frase secreta s\'utilitza per produir un valor de codi xifrat que es pot enviar a alguns recursos com a parmetre. El codi xifrat s el valor md5 de l\'adrea IP de l\'usuari concatenada amb la frase secreta. Aix permet que el recurs de destinaci verifiqui la connexi per a ms seguretat.';
$string['configwebsearch'] = 'Quan s\'est afegint un URL com a pgina web o com a enlla web, aquesta ubicaci s\'ofereix a l\'usuari per ajudar-lo a cercar l\'URL que desitgi.';
$string['configwindowsettings'] = 'Defineix el valor per defecte de la secci de configuraci de la Finestra quan s\'afegeixen alguns nous recursos. Desprs de la primera vegada esdev una preferncia individual de l\'usuari.';
$string['directlink'] = 'Enlla directe a aquest fitxer';
$string['directoryinfo'] = 'Es visualitzaran tots els fitxers del directori escollit.';
$string['display'] = 'Finestra';
$string['editingaresource'] = 'S\'est editant un recurs';
$string['encryptedcode'] = 'Codi xifrat';
$string['example'] = 'Exemple';
$string['exampleurl'] = 'http://www.example.com/somedirectory/somefile.html';
$string['fetchclienterror'] = 'Ha sorgit un error quan s\'intentava recuperar la pgina web (probablement l\'URL s erroni).';
$string['fetcherror'] = 'Ha sorgit un error quan s\'intentava recuperar la pgina web.';
$string['fetchservererror'] = 'Ha sorgit un error quan s\'intentava recuperar la pgina web (probablement un error de programa).</p>';
$string['filename'] = 'Nom del fitxer';
$string['filtername'] = 'Enllaos automtics a recursos';
$string['frameifpossible'] = 'Posa el recurs en un marc per mantenir visible la navegaci local';
$string['fulltext'] = 'Text complet';
$string['htmlfragment'] = 'Fragment HTML';
$string['maindirectory'] = 'Directori principal';
$string['modulename'] = 'Recurs';
$string['modulenameplural'] = 'Recursos';
$string['neverseen'] = 'Mai vist';
$string['newdirectories'] = 'Mostra la barra d\'enllaos del navegador';
$string['newfullscreen'] = 'Omple la pantalla completa';
$string['newheight'] = 'Alada per defecte de la finestra (en pxels)';
$string['newlocation'] = 'Mostra la barra d\'ubicaci';
$string['newmenubar'] = 'Mostra la barra de mens';
$string['newresizable'] = 'Permet redimensionar la finestra';
$string['newscrollbars'] = 'Permet el desplaament dins de la finestra';
$string['newstatus'] = 'Mostra la barra d\'estat';
$string['newtoolbar'] = 'Mostra la barra d\'eines';
$string['newwidth'] = 'Amplada de la finestra (en pxels)';
$string['newwindow'] = 'Nova finestra';
$string['newwindowopen'] = 'Mostra el material en una nova finestra emergent';
$string['note'] = 'Nota';
$string['notefile'] = 'Per penjar ms fitxers al curs (de manera que apareguin en aquesta llista) feu servir l\'<a href=$a >Gestor de fitxers</a>.';
$string['notypechosen'] = 'Heu de triar un tipus. Torneu enrere i proveu una altra vegada.';
$string['pagedisplay'] = 'Visualitza aquest recurs dins de la finestra actual';
$string['pagewindow'] = 'La mateixa finestra';
$string['parameter'] = 'Parmetre';
$string['parameters'] = 'Parmetres';
$string['popupresource'] = 'Aquest recurs ha d\'aparixer en una finestra emergent.';
$string['popupresourcelink'] = 'Si no, feu clic aqu: $a';
$string['resourcetype'] = 'Tipus de recurs';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina web';
$string['resourcetype3'] = 'Fitxer penjat';
$string['resourcetype4'] = 'Text';
$string['resourcetype5'] = 'Enlla web';
$string['resourcetype6'] = 'Text HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Text wiki';
$string['resourcetype9'] = 'Directori';
$string['resourcetypedirectory'] = 'Visualitza un directori';
$string['resourcetypefile'] = 'Enllaa un fitxer o lloc web';
$string['resourcetypehtml'] = 'Compon una pgina web';
$string['resourcetypelabel'] = 'Insereix una etiqueta';
$string['resourcetypetext'] = 'Compon una pgina de text';
$string['searchweb'] = 'Cerca una pgina web';
$string['variablename'] = 'Nom de variable';

?>
